@@ -3,6 +3,7 @@ from dataclasses import dataclass
 from typing import (
     Any,
     Callable,
+    Iterable,
     Mapping,
     NewType,
     Optional,
@@ -38,6 +39,7 @@ class ScalarDefinition(StrawberryType):
     serialize: Optional[Callable]
     parse_value: Optional[Callable]
     parse_literal: Optional[Callable]
+    directives: Iterable[object] = ()
 
     # Optionally store the GraphQLScalarType instance so that we don't get
     # duplicates
@@ -72,6 +74,7 @@ def _process_scalar(
     serialize: Optional[Callable] = None,
     parse_value: Optional[Callable] = None,
     parse_literal: Optional[Callable] = None,
+    directives: Iterable[object] = (),
 ):
     name = name or to_camel_case(cls.__name__)
 
@@ -83,6 +86,7 @@ def _process_scalar(
         serialize=serialize,
         parse_literal=parse_literal,
         parse_value=parse_value,
+        directives=directives,
     )
 
     return wrapper
@@ -97,6 +101,7 @@ def scalar(
     serialize: Callable = identity,
     parse_value: Optional[Callable] = None,
     parse_literal: Optional[Callable] = None,
+    directives: Iterable[object] = (),
 ) -> Callable[[_T], _T]:
     ...
 
@@ -111,6 +116,7 @@ def scalar(
     serialize: Callable = identity,
     parse_value: Optional[Callable] = None,
     parse_literal: Optional[Callable] = None,
+    directives: Iterable[object] = (),
 ) -> _T:
     ...
 
@@ -127,6 +133,7 @@ def scalar(
     serialize: Callable = identity,
     parse_value: Optional[Callable] = None,
     parse_literal: Optional[Callable] = None,
+    directives: Iterable[object] = (),
 ) -> Any:
     """Annotates a class or type as a GraphQL custom scalar.
 
@@ -166,6 +173,7 @@ def scalar(
             serialize=serialize,
             parse_value=parse_value,
             parse_literal=parse_literal,
+            directives=directives,
         )
 
     if cls is None:
