@@ -3,15 +3,14 @@ import sys
 from typing import Dict, List, Type
 
 from strawberry.annotation import StrawberryAnnotation
+from strawberry.arguments import UNSET
 from strawberry.exceptions import (
     FieldWithResolverAndDefaultFactoryError,
     FieldWithResolverAndDefaultValueError,
     PrivateStrawberryFieldError,
 )
 from strawberry.field import StrawberryField
-from strawberry.private import Private
-
-from ..arguments import UNSET
+from strawberry.private import is_private
 
 
 def _get_fields(cls: Type) -> List[StrawberryField]:
@@ -81,12 +80,13 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
 
         if isinstance(field, StrawberryField):
             # Check that the field type is not Private
-            if isinstance(field.type, Private):
+            if is_private(field.type):
                 raise PrivateStrawberryFieldError(field.python_name, cls.__name__)
 
             # Check that default is not set if a resolver is defined
             if (
                 field.default is not dataclasses.MISSING
+                and field.default is not UNSET
                 and field.base_resolver is not None
             ):
                 raise FieldWithResolverAndDefaultValueError(
@@ -96,8 +96,10 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
             # Check that default_factory is not set if a resolver is defined
             # Note: using getattr because of this issue:
             # https://github.com/python/mypy/issues/6910
+            default_factory = getattr(field, "default_factory", None)
             if (
-                getattr(field, "default_factory") is not dataclasses.MISSING  # noqa
+                default_factory is not dataclasses.MISSING
+                and default_factory is not UNSET
                 and field.base_resolver is not None
             ):
                 raise FieldWithResolverAndDefaultFactoryError(
@@ -125,7 +127,7 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
         # Create a StrawberryField for fields that didn't use strawberry.field
         else:
             # Only ignore Private fields that weren't defined using StrawberryFields
-            if isinstance(field.type, Private):
+            if is_private(field.type):
                 continue
 
             field_type = field.type
@@ -142,7 +144,7 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
                     namespace=module.__dict__,
                 ),
                 origin=origin,
-                default=getattr(cls, field.name, UNSET),
+                default=getattr(cls, field.name, dataclasses.MISSING),
             )
 
         field_name = field.python_name
