@@ -1,12 +1,7 @@
 import datetime
 import json
 from json import JSONEncoder
-from typing import Any, Dict
-
-from pygments import highlight, lexers
-from pygments.formatters import Terminal256Formatter
-
-from .graphql_lexer import GraphQLLexer
+from typing import Any, Dict, Optional
 
 
 class StrawberryJSONEncoder(JSONEncoder):
@@ -15,12 +10,23 @@ class StrawberryJSONEncoder(JSONEncoder):
 
 
 def pretty_print_graphql_operation(
-    operation_name: str, query: str, variables: Dict["str", Any]
+    operation_name: Optional[str], query: str, variables: Optional[Dict["str", Any]]
 ):
     """Pretty print a GraphQL operation using pygments.
 
     Won't print introspection operation to prevent noise in the output."""
 
+    try:
+        from pygments import highlight, lexers
+        from pygments.formatters import Terminal256Formatter
+    except ImportError as e:
+        raise ImportError(
+            "pygments is not installed but is required for debug output, install it "
+            "directly or run `pip install strawberry-graphql[debug-server]`"
+        ) from e
+
+    from .graphql_lexer import GraphQLLexer
+
     if operation_name == "IntrospectionQuery":
         return
 
